// Lookup Service interface which retrieves information from the database
// which is then sent to the client.
// Authors:
// Cameron Hayes
// Mac ...
// Elias Sarraf

unit Lookup.Service;

interface

uses
  XData.Service.Common,
  Aurelius.Mapping.Attributes,
  System.JSON,
  System.Generics.Collections,
  System.Classes;

const
  API_MODEL = 'Api';

type

  TUserItem = class
  public
    userID: string;
    username: string;
    password: string;
    full_name: string;
    status: string;
    email_address: string;
    Atype: string;
    rights: integer;
    perspectiveID: string;
    QBID: string;
  end;

  TUserList = class
  public
    count: integer;
    data: TList<TUserItem>;
  end;

  TItemItem = class
  public
    ID: string;
    name: string;
    description: string;
    status: string;
  end;

  TItemList = class
  public
    count: integer;
    data: TList<TItemItem>;
  end;

  TOrderItem = class
  public
     ID: string;
     companyName: string;
     jobName: string;
     orderDate: string;
     proofDue: string;
     proofDone: string;
     artDue: string;
     artDone: string;
     mountDue: string;
     mountDone: string;
     shipDue: string;
     shipDone: string;
     price: string;
     qbRefNum: string;
     colors: string;
  end;

  TOrderList = class
  Public
    count: integer;
    data: TList<TOrderItem>
  end;



type
  [ServiceContract]
  ILookupService = interface(IInvokable)
    ['{F24E1468-5279-401F-A877-CD48B44F4416}']
    [HttpGet] function Search(phoneNum: string): TOrderList;
    [HttpGet] function GetUsers(searchOptions: string): TUserList;
    [HttpGet] function GetItems(searchOptions: string): TItemList;
    [HttpGet] function GetOrders(searchOptions: string): TOrderList;
    function AddUser(userInfo: string): string;
    function AddItem(itemInfo: string): string;
    function DelUser(username: string): string;
    function EditUser(const editOptions: string): string;
  end;

implementation

initialization
  RegisterServiceType(TypeInfo(ILookupService));

end.
